==> xiaoerke-common-1.0.103-sources.jar: com/cxqm/xiaoerke/common/web/CKFAliyunFileUploadCommand.java <==
package com.cxqm.xiaoerke.common.web;

/**
 * Created by yanghb on 17/3/9.
 */
//
// Source code recreated from a .class file by IntelliJ IDEA
// (powered by Fernflower decompiler)
//

import com.ckfinder.connector.configuration.Events;
import com.ckfinder.connector.configuration.IConfiguration;
import com.ckfinder.connector.data.AfterFileUploadEventArgs;
import com.ckfinder.connector.data.ResourceType;
import com.ckfinder.connector.errors.ConnectorException;
import com.ckfinder.connector.errors.ErrorUtils;
import com.ckfinder.connector.handlers.command.Command;
import com.ckfinder.connector.handlers.command.IPostCommand;
import com.ckfinder.connector.utils.AccessControlUtil;
import com.ckfinder.connector.utils.FileUtils;
import com.ckfinder.connector.utils.ImageUtils;
import com.cxqm.xiaoerke.common.utils.IdGen;
import com.cxqm.xiaoerke.common.utils.OSSObjectTool;
import com.cxqm.xiaoerke.common.utils.RandomUtils;
import com.cxqm.xiaoerke.modules.sys.security.SystemAuthorizingRealm;
import com.cxqm.xiaoerke.modules.sys.utils.UserUtils;
import org.apache.commons.fileupload.FileItem;
import org.apache.commons.fileupload.FileUploadBase;
import org.apache.commons.fileupload.disk.DiskFileItemFactory;
import org.apache.commons.fileupload.servlet.ServletFileUpload;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.IOException;
import java.io.OutputStream;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;


public class CKFAliyunFileUploadCommand extends Command implements IPostCommand {
	protected String fileName = "";
	protected String newFileName = "";
	protected String ckEditorFuncNum;
	protected String responseType;
	protected String ckFinderFuncNum;
	private String langCode;
	protected boolean uploaded;
	protected int errorCode = 0;
	private static final char[] UNSAFE_FILE_NAME_CHARS = new char[]{':', '*', '?', '|', '/'};

	private String buket_key;

	private String userId;

	public CKFAliyunFileUploadCommand() {
		this.type = "";
		this.uploaded = false;
	}

	public void execute(OutputStream out) throws ConnectorException {
		if(this.configuration.isDebugMode() && this.exception != null) {
			throw new ConnectorException(this.errorCode, this.exception);
		} else {
			try {
				String e = this.errorCode == 0?"": ErrorUtils.getInstance().getErrorMsgByLangAndCode(this.langCode, this.errorCode, this.configuration);
				e = e.replaceAll("%1", this.newFileName);
				String path = "";
				if(!this.uploaded) {
					this.newFileName = "";
					this.currentFolder = "";
				} else {
					path = ((ResourceType)this.configuration.getTypes().get(this.type)).getUrl() + this.currentFolder;
				}

				if(this.responseType != null && this.responseType.equals("txt")) {
					out.write((this.newFileName + "|" + e).getBytes("UTF-8"));
				} else {
					out.write("<script type=\"text/javascript\">".getBytes("UTF-8"));
					if(this.checkFuncNum()) {
						this.handleOnUploadCompleteCallFuncResponse(out, e, path);
					} else {
						this.handleOnUploadCompleteResponse(out, e);
					}

					out.write("</script>".getBytes("UTF-8"));
				}

			} catch (IOException var4) {
				throw new ConnectorException(104, var4);
			}
		}
	}

	protected boolean checkFuncNum() {
		return this.ckFinderFuncNum != null;
	}

	protected void handleOnUploadCompleteCallFuncResponse(OutputStream out, String errorMsg, String path) throws IOException {
		this.ckFinderFuncNum = this.ckFinderFuncNum.replaceAll("[^\\d]", "");
		out.write(("window.parent.CKFinder.tools.callFunction(" + this.ckFinderFuncNum + ", \'" + path + FileUtils.backupWithBackSlash(this.newFileName, "\'") + "\', \'" + errorMsg + "\');").getBytes("UTF-8"));
	}

	protected void handleOnUploadCompleteResponse(OutputStream out, String errorMsg) throws IOException {
		out.write("window.parent.OnUploadCompleted(".getBytes("UTF-8"));
		out.write(("\'" + FileUtils.backupWithBackSlash(this.newFileName, "\'") + "\'").getBytes("UTF-8"));
		out.write((", \'" + (this.errorCode != 0?errorMsg:"") + "\'").getBytes("UTF-8"));
		out.write(");".getBytes("UTF-8"));
	}

	public void initParams(HttpServletRequest request, IConfiguration configuration, Object... params) throws ConnectorException {
		super.initParams(request, configuration, params);
		this.ckFinderFuncNum = request.getParameter("CKFinderFuncNum");
		this.ckEditorFuncNum = request.getParameter("CKEditorFuncNum");
		this.responseType = request.getParameter("response_type");
		this.langCode = request.getParameter("langCode");
		if(this.errorCode == 0) {
			this.uploaded = this.uploadFile(request);
		}

	}

	private boolean uploadFile(HttpServletRequest request) {
		if(!AccessControlUtil.getInstance(this.configuration).checkFolderACL(this.type, this.currentFolder, this.userRole, 32)) {
			this.errorCode = 103;
			return false;
		} else {
			return this.fileUpload(request);
		}
	}

	private boolean fileUpload(HttpServletRequest request) {
		try {
			DiskFileItemFactory e = new DiskFileItemFactory();
			ServletFileUpload uploadHandler = new ServletFileUpload(e);
			List items = uploadHandler.parseRequest(request);
			Iterator i$ = items.iterator();

			while(true) {
				FileItem item;
				do {
					if(!i$.hasNext()) {
						return false;
					}

					item = (FileItem)i$.next();
				} while(item.isFormField());

				String path = ((ResourceType)this.configuration.getTypes().get(this.type)).getPath() + this.currentFolder;
//				this.fileName = this.getFileItemName(item);
				String fName = this.getFileItemName(item);
				String ext = "";
				int extPointIndex = fName.lastIndexOf('.');
				if (extPointIndex > 0) {
					ext = fName.substring(extPointIndex);
				}

				int r = new java.util.Random().nextInt(900)+100;	// 随机三位数，一定程度上解决并发

				this.fileName = new SimpleDateFormat("yyyyMMddHHmmssSSS").format(new Date()) + "_" + r + ext;

				try {
					if(this.validateUploadItem(item, path)) {
						SystemAuthorizingRealm.Principal principal = (SystemAuthorizingRealm.Principal) UserUtils.getPrincipal();
						Map<String, ResourceType> types = this.configuration.getTypes();
						String typeName = ((ResourceType) types.get(this.type)).getName();
						OSSObjectTool.uploadFile(buket_key == null || buket_key.trim().equals("") ? OSSObjectTool.BUCKET_BACKEND_PIC : buket_key, userId == null || userId.trim().equals("") ? principal.getId() : userId + "/" + typeName +this.currentFolder+this.fileName,item.getInputStream());
						return true;

					}
				} finally {
					item.delete();
				}
			}
		} catch (FileUploadBase.InvalidContentTypeException var18) {
			if(this.configuration.isDebugMode()) {
				this.exception = var18;
			}

			this.errorCode = 204;
			return false;
		} catch (FileUploadBase.IOFileUploadException var19) {
			if(this.configuration.isDebugMode()) {
				this.exception = var19;
			}

			this.errorCode = 104;
			return false;
		} catch (FileUploadBase.SizeLimitExceededException var20) {
			this.errorCode = 203;
			return false;
		} catch (FileUploadBase.FileSizeLimitExceededException var21) {
			this.errorCode = 203;
			return false;
		} catch (Exception var23) {
			if(this.configuration.isDebugMode()) {
				this.exception = var23;
			}

			this.errorCode = 104;
			return false;
		}
	}

	private boolean saveTemporaryFile(String path, FileItem item) throws Exception {
		File file = new File(path, this.newFileName);
		AfterFileUploadEventArgs args = new AfterFileUploadEventArgs();
		args.setCurrentFolder(this.currentFolder);
		args.setFile(file);
		args.setFileContent(item.get());
		if(!ImageUtils.isImage(file)) {
			item.write(file);
			if(this.configuration.getEvents() != null) {
				this.configuration.getEvents().run(Events.EventTypes.AfterFileUpload, args, this.configuration);
			}

			return true;
		} else if(ImageUtils.checkImageSize(item.getInputStream(), this.configuration)) {
			ImageUtils.createTmpThumb(item.getInputStream(), file, this.getFileItemName(item), this.configuration);
			if(this.configuration.getEvents() != null) {
				this.configuration.getEvents().run(Events.EventTypes.AfterFileUpload, args, this.configuration);
			}

			return true;
		} else if(this.configuration.checkSizeAfterScaling()) {
			ImageUtils.createTmpThumb(item.getInputStream(), file, this.getFileItemName(item), this.configuration);
			if(FileUtils.checkFileSize((ResourceType)this.configuration.getTypes().get(this.type), file.length())) {
				if(this.configuration.getEvents() != null) {
					this.configuration.getEvents().run(Events.EventTypes.AfterFileUpload, args, this.configuration);
				}

				return true;
			} else {
				file.delete();
				this.errorCode = 203;
				return false;
			}
		} else {
			return false;
		}
	}

	private String getFinalFileName(String path, String name) {
		File file = new File(path, name);

		for(int number = 0; file.exists(); this.errorCode = 201) {
			++number;
			StringBuilder sb = new StringBuilder();
			sb.append(FileUtils.getFileNameWithoutExtension(name));
			sb.append("(" + number + ").");
			sb.append(FileUtils.getFileExtension(name));
			this.newFileName = sb.toString();
			file = new File(path, this.newFileName);
		}

		return this.newFileName;
	}

	private boolean validateUploadItem(FileItem item, String path) {
		// 改用aliyun 直接返回true
		return true;
	}

	public void setResponseHeader(HttpServletResponse response, ServletContext sc) {
		response.setCharacterEncoding("utf-8");
		response.setContentType("text/html");
	}

	private String getFileItemName(FileItem item) {
		Pattern p = Pattern.compile("[^\\\\/]+$");
		Matcher m = p.matcher(item.getName());
		return m.find()?m.group(0):"";
	}

	protected boolean checkParam(String reqParam) throws ConnectorException {
		if(reqParam != null && !reqParam.equals("")) {
			if(Pattern.compile("(/\\.|\\p{Cntrl}|//|\\\\|[:*?<>\"\\|])").matcher(reqParam).find()) {
				this.errorCode = 102;
				return false;
			} else {
				return true;
			}
		} else {
			return true;
		}
	}

	protected boolean checkHidden() throws ConnectorException {
		if(FileUtils.checkIfDirIsHidden(this.currentFolder, this.configuration)) {
			this.errorCode = 109;
			return true;
		} else {
			return false;
		}
	}

	protected boolean checkConnector(HttpServletRequest request) throws ConnectorException {
		if(this.configuration.enabled() && this.configuration.checkAuthentication(request)) {
			return true;
		} else {
			this.errorCode = 500;
			return false;
		}
	}

	protected boolean checkIfCurrFolderExists(HttpServletRequest request) throws ConnectorException {
//		String tmpType = this.getParameter(request, "type");
//		File currDir = new File(((ResourceType)this.configuration.getTypes().get(tmpType)).getPath() + this.currentFolder);
//		if(currDir.exists() && currDir.isDirectory()) {
//			return true;
//		} else {
//			this.errorCode = 116;
//			return false;
//		}
		return  true;
	}

	public String getBuket_key() {
		return buket_key;
	}

	public void setBuket_key(String buket_key) {
		this.buket_key = buket_key;
	}

	public String getUserId() {
		return userId;
	}

	public void setUserId(String userId) {
		this.userId = userId;
	}
}

==> xiaoerke-common-1.0.106-sources.jar: com/cxqm/xiaoerke/common/web/CKFAliyunFileUploadCommand.java <==
package com.cxqm.xiaoerke.common.web;

/**
 * Created by yanghb on 17/3/9.
 */
//
// Source code recreated from a .class file by IntelliJ IDEA
// (powered by Fernflower decompiler)
//

import com.ckfinder.connector.configuration.Events;
import com.ckfinder.connector.configuration.IConfiguration;
import com.ckfinder.connector.data.AfterFileUploadEventArgs;
import com.ckfinder.connector.data.ResourceType;
import com.ckfinder.connector.errors.ConnectorException;
import com.ckfinder.connector.errors.ErrorUtils;
import com.ckfinder.connector.handlers.command.Command;
import com.ckfinder.connector.handlers.command.IPostCommand;
import com.ckfinder.connector.utils.AccessControlUtil;
import com.ckfinder.connector.utils.FileUtils;
import com.ckfinder.connector.utils.ImageUtils;
import com.cxqm.xiaoerke.common.filter.CKFAliyunBukert;
import com.cxqm.xiaoerke.common.utils.IdGen;
import com.cxqm.xiaoerke.common.utils.OSSObjectTool;
import com.cxqm.xiaoerke.common.utils.RandomUtils;
import com.cxqm.xiaoerke.modules.sys.security.SystemAuthorizingRealm;
import com.cxqm.xiaoerke.modules.sys.utils.UserUtils;
import org.apache.commons.fileupload.FileItem;
import org.apache.commons.fileupload.FileUploadBase;
import org.apache.commons.fileupload.disk.DiskFileItemFactory;
import org.apache.commons.fileupload.servlet.ServletFileUpload;
import org.springframework.beans.factory.annotation.Autowired;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.IOException;
import java.io.OutputStream;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;


public class CKFAliyunFileUploadCommand extends Command implements IPostCommand {
	protected String fileName = "";
	protected String newFileName = "";
	protected String ckEditorFuncNum;
	protected String responseType;
	protected String ckFinderFuncNum;
	private String langCode;
	protected boolean uploaded;
	protected int errorCode = 0;
	private static final char[] UNSAFE_FILE_NAME_CHARS = new char[]{':', '*', '?', '|', '/'};

	public CKFAliyunFileUploadCommand() {
		this.type = "";
		this.uploaded = false;
	}

	public void execute(OutputStream out) throws ConnectorException {
		if(this.configuration.isDebugMode() && this.exception != null) {
			throw new ConnectorException(this.errorCode, this.exception);
		} else {
			try {
				String e = this.errorCode == 0?"": ErrorUtils.getInstance().getErrorMsgByLangAndCode(this.langCode, this.errorCode, this.configuration);
				e = e.replaceAll("%1", this.newFileName);
				String path = "";
				if(!this.uploaded) {
					this.newFileName = "";
					this.currentFolder = "";
				} else {
					path = ((ResourceType)this.configuration.getTypes().get(this.type)).getUrl() + this.currentFolder;
				}

				if(this.responseType != null && this.responseType.equals("txt")) {
					out.write((this.newFileName + "|" + e).getBytes("UTF-8"));
				} else {
					out.write("<script type=\"text/javascript\">".getBytes("UTF-8"));
					if(this.checkFuncNum()) {
						this.handleOnUploadCompleteCallFuncResponse(out, e, path);
					} else {
						this.handleOnUploadCompleteResponse(out, e);
					}

					out.write("</script>".getBytes("UTF-8"));
				}

			} catch (IOException var4) {
				throw new ConnectorException(104, var4);
			}
		}
	}

	protected boolean checkFuncNum() {
		return this.ckFinderFuncNum != null;
	}

	protected void handleOnUploadCompleteCallFuncResponse(OutputStream out, String errorMsg, String path) throws IOException {
		this.ckFinderFuncNum = this.ckFinderFuncNum.replaceAll("[^\\d]", "");
		out.write(("window.parent.CKFinder.tools.callFunction(" + this.ckFinderFuncNum + ", \'" + path + FileUtils.backupWithBackSlash(this.newFileName, "\'") + "\', \'" + errorMsg + "\');").getBytes("UTF-8"));
	}

	protected void handleOnUploadCompleteResponse(OutputStream out, String errorMsg) throws IOException {
		out.write("window.parent.OnUploadCompleted(".getBytes("UTF-8"));
		out.write(("\'" + FileUtils.backupWithBackSlash(this.newFileName, "\'") + "\'").getBytes("UTF-8"));
		out.write((", \'" + (this.errorCode != 0?errorMsg:"") + "\'").getBytes("UTF-8"));
		out.write(");".getBytes("UTF-8"));
	}

	public void initParams(HttpServletRequest request, IConfiguration configuration, Object... params) throws ConnectorException {
		super.initParams(request, configuration, params);
		this.ckFinderFuncNum = request.getParameter("CKFinderFuncNum");
		this.ckEditorFuncNum = request.getParameter("CKEditorFuncNum");
		this.responseType = request.getParameter("response_type");
		this.langCode = request.getParameter("langCode");
		if(this.errorCode == 0) {
			this.uploaded = this.uploadFile(request);
		}

	}

	private boolean uploadFile(HttpServletRequest request) {
		if(!AccessControlUtil.getInstance(this.configuration).checkFolderACL(this.type, this.currentFolder, this.userRole, 32)) {
			this.errorCode = 103;
			return false;
		} else {
			return this.fileUpload(request);
		}
	}

	private boolean fileUpload(HttpServletRequest request) {
		try {
			DiskFileItemFactory e = new DiskFileItemFactory();
			ServletFileUpload uploadHandler = new ServletFileUpload(e);
			List items = uploadHandler.parseRequest(request);
			Iterator i$ = items.iterator();

			while(true) {
				FileItem item;
				do {
					if(!i$.hasNext()) {
						return false;
					}

					item = (FileItem)i$.next();
				} while(item.isFormField());

				String path = ((ResourceType)this.configuration.getTypes().get(this.type)).getPath() + this.currentFolder;
//				this.fileName = this.getFileItemName(item);
				String fName = this.getFileItemName(item);
				String ext = "";
				int extPointIndex = fName.lastIndexOf('.');
				if (extPointIndex > 0) {
					ext = fName.substring(extPointIndex);
				}

				int r = new java.util.Random().nextInt(900)+100;	// 随机三位数，一定程度上解决并发

				this.fileName = new SimpleDateFormat("yyyyMMddHHmmssSSS").format(new Date()) + "_" + r + ext;

				try {
					if(this.validateUploadItem(item, path)) {

						String buket_key = CKFAliyunBukert.getBuketKey();
						String userId = CKFAliyunBukert.getUserId();

						SystemAuthorizingRealm.Principal principal = (SystemAuthorizingRealm.Principal) UserUtils.getPrincipal();
						Map<String, ResourceType> types = this.configuration.getTypes();
						String typeName = ((ResourceType) types.get(this.type)).getName();
						OSSObjectTool.uploadFile(buket_key == null || buket_key.trim().equals("") ? OSSObjectTool.BUCKET_BACKEND_PIC : buket_key, userId == null || userId.trim().equals("") ? principal.getId() : "/" + userId + "/" + typeName +this.currentFolder+this.fileName,item.getInputStream());
						return true;

					}
				} finally {
					item.delete();
				}
			}
		} catch (FileUploadBase.InvalidContentTypeException var18) {
			if(this.configuration.isDebugMode()) {
				this.exception = var18;
			}

			this.errorCode = 204;
			return false;
		} catch (FileUploadBase.IOFileUploadException var19) {
			if(this.configuration.isDebugMode()) {
				this.exception = var19;
			}

			this.errorCode = 104;
			return false;
		} catch (FileUploadBase.SizeLimitExceededException var20) {
			this.errorCode = 203;
			return false;
		} catch (FileUploadBase.FileSizeLimitExceededException var21) {
			this.errorCode = 203;
			return false;
		} catch (Exception var23) {
			if(this.configuration.isDebugMode()) {
				this.exception = var23;
			}

			this.errorCode = 104;
			return false;
		}
	}

	private boolean saveTemporaryFile(String path, FileItem item) throws Exception {
		File file = new File(path, this.newFileName);
		AfterFileUploadEventArgs args = new AfterFileUploadEventArgs();
		args.setCurrentFolder(this.currentFolder);
		args.setFile(file);
		args.setFileContent(item.get());
		if(!ImageUtils.isImage(file)) {
			item.write(file);
			if(this.configuration.getEvents() != null) {
				this.configuration.getEvents().run(Events.EventTypes.AfterFileUpload, args, this.configuration);
			}

			return true;
		} else if(ImageUtils.checkImageSize(item.getInputStream(), this.configuration)) {
			ImageUtils.createTmpThumb(item.getInputStream(), file, this.getFileItemName(item), this.configuration);
			if(this.configuration.getEvents() != null) {
				this.configuration.getEvents().run(Events.EventTypes.AfterFileUpload, args, this.configuration);
			}

			return true;
		} else if(this.configuration.checkSizeAfterScaling()) {
			ImageUtils.createTmpThumb(item.getInputStream(), file, this.getFileItemName(item), this.configuration);
			if(FileUtils.checkFileSize((ResourceType)this.configuration.getTypes().get(this.type), file.length())) {
				if(this.configuration.getEvents() != null) {
					this.configuration.getEvents().run(Events.EventTypes.AfterFileUpload, args, this.configuration);
				}

				return true;
			} else {
				file.delete();
				this.errorCode = 203;
				return false;
			}
		} else {
			return false;
		}
	}

	private String getFinalFileName(String path, String name) {
		File file = new File(path, name);

		for(int number = 0; file.exists(); this.errorCode = 201) {
			++number;
			StringBuilder sb = new StringBuilder();
			sb.append(FileUtils.getFileNameWithoutExtension(name));
			sb.append("(" + number + ").");
			sb.append(FileUtils.getFileExtension(name));
			this.newFileName = sb.toString();
			file = new File(path, this.newFileName);
		}

		return this.newFileName;
	}

	private boolean validateUploadItem(FileItem item, String path) {
		// 改用aliyun 直接返回true
		return true;
	}

	public void setResponseHeader(HttpServletResponse response, ServletContext sc) {
		response.setCharacterEncoding("utf-8");
		response.setContentType("text/html");
	}

	private String getFileItemName(FileItem item) {
		Pattern p = Pattern.compile("[^\\\\/]+$");
		Matcher m = p.matcher(item.getName());
		return m.find()?m.group(0):"";
	}

	protected boolean checkParam(String reqParam) throws ConnectorException {
		if(reqParam != null && !reqParam.equals("")) {
			if(Pattern.compile("(/\\.|\\p{Cntrl}|//|\\\\|[:*?<>\"\\|])").matcher(reqParam).find()) {
				this.errorCode = 102;
				return false;
			} else {
				return true;
			}
		} else {
			return true;
		}
	}

	protected boolean checkHidden() throws ConnectorException {
		if(FileUtils.checkIfDirIsHidden(this.currentFolder, this.configuration)) {
			this.errorCode = 109;
			return true;
		} else {
			return false;
		}
	}

	protected boolean checkConnector(HttpServletRequest request) throws ConnectorException {
		if(this.configuration.enabled() && this.configuration.checkAuthentication(request)) {
			return true;
		} else {
			this.errorCode = 500;
			return false;
		}
	}

	protected boolean checkIfCurrFolderExists(HttpServletRequest request) throws ConnectorException {
//		String tmpType = this.getParameter(request, "type");
//		File currDir = new File(((ResourceType)this.configuration.getTypes().get(tmpType)).getPath() + this.currentFolder);
//		if(currDir.exists() && currDir.isDirectory()) {
//			return true;
//		} else {
//			this.errorCode = 116;
//			return false;
//		}
		return  true;
	}
}
